=======
Credits
=======

Development Lead
----------------

* zfit <zfit@physik.uzh.ch>

Contributors
------------

| Jonas Eschle <jonas.eschle@cern.ch>
| Albert Puig <albert.puig@cern.ch>
| Rafael Silva Coutinho <rsilvaco@cern.ch>

